==> jc-1.4.0.tar.gz: javax/print/attribute/AttributeSetUtilities.h <==
// public final class javax.print.attribute.AttributeSetUtilities

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4a41b37aece88ad8 javax_print_attribute_AttributeSetUtilities

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities_H_
#define _JC_javax_print_attribute_AttributeSetUtilities_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_print_attribute_Attribute$object;
struct _jc_javax_print_attribute_AttributeSet$object;
struct _jc_javax_print_attribute_DocAttributeSet$object;
struct _jc_javax_print_attribute_PrintJobAttributeSet$object;
struct _jc_javax_print_attribute_PrintRequestAttributeSet$object;
struct _jc_javax_print_attribute_PrintServiceAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities$refs	_jc_javax_print_attribute_AttributeSetUtilities$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities$object	_jc_javax_print_attribute_AttributeSetUtilities$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities$vmethods	_jc_javax_print_attribute_AttributeSetUtilities$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities$vtable	_jc_javax_print_attribute_AttributeSetUtilities$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities$vtype	_jc_javax_print_attribute_AttributeSetUtilities$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities$object *);

// Static methods
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$synchronizedView$d67620eb15f7cdcf(_jc_env *, struct _jc_object *);
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$synchronizedView$79586aeea0e69e66(_jc_env *, struct _jc_object *);
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$synchronizedView$1f5a30659077e2e5(_jc_env *, struct _jc_object *);
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$synchronizedView$b6409f0744d13bd5(_jc_env *, struct _jc_object *);
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$synchronizedView$76a7e17a7be32bc0(_jc_env *, struct _jc_object *);
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$unmodifiableView$6ec1094ab2075767(_jc_env *, struct _jc_object *);
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$unmodifiableView$221912527d906034(_jc_env *, struct _jc_object *);
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$unmodifiableView$28260b4cbe440f45(_jc_env *, struct _jc_object *);
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$unmodifiableView$060e907e197b4071(_jc_env *, struct _jc_object *);
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$unmodifiableView$874637311cab7c7b(_jc_env *, struct _jc_object *);
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_AttributeSetUtilities$method$verifyAttributeCategory$cfcd3b27472dd7c0(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *);
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$verifyAttributeValue$b83fbd67d4299d66(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *);
extern void _jc_javax_print_attribute_AttributeSetUtilities$method$verifyCategoryForValue$881885a4edc9a211(_jc_env *, struct _jc_java_lang_Class$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities$vmethods	javax_print_attribute_AttributeSetUtilities;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities$refs {
    _jc_javax_print_attribute_AttributeSetUtilities$sub_refs	javax_print_attribute_AttributeSetUtilities;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities$sub_nonrefs	javax_print_attribute_AttributeSetUtilities;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities$object {
	_jc_javax_print_attribute_AttributeSetUtilities$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities$vtype _jc_javax_print_attribute_AttributeSetUtilities$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/AttributeSetUtilities.h <==
// public final class javax.print.attribute.AttributeSetUtilities

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4a41b37aece88ad8 javax_print_attribute_AttributeSetUtilities

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities_H_
#define _JC_javax_print_attribute_AttributeSetUtilities_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_print_attribute_Attribute$object;
struct _jc_javax_print_attribute_AttributeSet$object;
struct _jc_javax_print_attribute_DocAttributeSet$object;
struct _jc_javax_print_attribute_PrintJobAttributeSet$object;
struct _jc_javax_print_attribute_PrintRequestAttributeSet$object;
struct _jc_javax_print_attribute_PrintServiceAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities$refs	_jc_javax_print_attribute_AttributeSetUtilities$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities$object	_jc_javax_print_attribute_AttributeSetUtilities$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities$vmethods	_jc_javax_print_attribute_AttributeSetUtilities$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities$vtable	_jc_javax_print_attribute_AttributeSetUtilities$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities$vtype	_jc_javax_print_attribute_AttributeSetUtilities$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$synchronizedView$d67620eb15f7cdcf(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$synchronizedView$79586aeea0e69e66(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$synchronizedView$1f5a30659077e2e5(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$synchronizedView$b6409f0744d13bd5(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$synchronizedView$76a7e17a7be32bc0(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$unmodifiableView$6ec1094ab2075767(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$unmodifiableView$221912527d906034(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$unmodifiableView$28260b4cbe440f45(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$unmodifiableView$060e907e197b4071(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$unmodifiableView$874637311cab7c7b(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_AttributeSetUtilities$method$verifyAttributeCategory$cfcd3b27472dd7c0(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_print_attribute_AttributeSetUtilities$method$verifyAttributeValue$b83fbd67d4299d66(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_AttributeSetUtilities$method$verifyCategoryForValue$881885a4edc9a211(_jc_env *, struct _jc_java_lang_Class$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities$vmethods	javax_print_attribute_AttributeSetUtilities;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities$refs {
    _jc_javax_print_attribute_AttributeSetUtilities$sub_refs	javax_print_attribute_AttributeSetUtilities;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities$sub_nonrefs	javax_print_attribute_AttributeSetUtilities;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities$object {
	_jc_javax_print_attribute_AttributeSetUtilities$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities$vtype _jc_javax_print_attribute_AttributeSetUtilities$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities_H_ */
